<template>
  <Card class="attention-card-wrapper">
    <div class="attention-card-inner">
      <InfoAvatar
        :src="avatarUrl ? setOSSLink(avatarUrl) : ''"
        :name="name"
        :company="enterpriseName"
        class="attention-card-avatar"
        :size="size"
      />
      <div class="attention-card-actions">
        <slot name="actions" />
      </div>
    </div>
  </Card>
</template>

<script setup lang="ts">
import Card from './Card.vue';
import { InfoAvatar } from '@12333/components';
import { setOSSLink } from '@12333/utils';

defineOptions({
  name: 'AttentionCard',
});

type Props = {
  avatarUrl?: string;
  name?: string;
  enterpriseName?: string;
  size?: 'normal' | 'small';
};

const props = withDefaults(defineProps<Props>(), {
  size: 'normal',
});
</script>

<style lang="scss">
@import '@/styles/common.scss';

.attention-card-wrapper {
  border-radius: 0;
  padding: 0 boleGetCssVar('size', 'body-padding-h');
  margin-bottom: 0;

  &:last-child {
    .attention-card-inner {
      border-bottom: none;
    }
  }

  .attention-card-inner {
    border-bottom: 2px solid #f6f6f6;
    padding: 32px 0;
    display: flex;
    align-items: center;

    .attention-card-avatar {
      flex: 1;
      min-width: 0;
    }

    .attention-card-actions {
      display: flex;
      align-items: center;

      .card-action {
        --nut-button-default-height: 48px;
        border: 2px solid boleGetCssVar('text-color', 'secondary');
        font-weight: bold;
        font-size: 24px;
        color: boleGetCssVar('text-color', 'primary');
        padding: 0 30px;
      }
    }
  }
}
</style>
